==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-bottom-split-pane/xl-react-widget-collapsible-bottom-split-pane-component.js <==
import PropTypes from 'prop-types';
import React, {Component} from 'react';
import SplitPane from 'react-split-pane';
import classnames from 'classnames';
import {localeMessages} from '../../../services/locale-service';

import './xl-react-widget-collapsible-bottom-split-pane.less';

export class XlReactWidgetCollapsibleBottomSplitPanel extends Component {
    static propTypes = {
        children: PropTypes.arrayOf(PropTypes.element.isRequired),
        defaultBottomPaneHeight: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        minSizeBottom: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        minSizeTop: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
    };

    state = {isBottomVisible: false};

    handleDisplayToggle = () => {
        if (this.state.isBottomVisible) {
            this.hideBottomPane();
        } else {
            this.showBottomPane();
        }
    };

    handlePaneHeightChange = (size) => {
        this.setState({isBottomVisible: size > this.props.minSizeBottom});
    };

    showBottomPane = () => {
        if (!this.state.isBottomVisible) {
            this.setState({
                bottomPaneHeight: this.props.defaultBottomPaneHeight,
                isBottomVisible: true
            });
        }
    };

    hideBottomPane = () => {
        if (this.state.isBottomVisible) {
            this.setState({
                bottomPaneHeight: this.props.minSizeBottom,
                isBottomVisible: false
            });
        }
    };

    render() {
        const {bottomPaneHeight, isBottomVisible} = this.state;
        const {minSizeTop, minSizeBottom, children} = this.props;
        const splitPaneClass = classnames({visible: isBottomVisible}, 'hideable-split-pane');
        const toggleClass = classnames('toggle', {
            'toggle-hide': isBottomVisible,
            'toggle-show': !isBottomVisible
        });
        const toggleButton = <span className={toggleClass} onClick={this.handleDisplayToggle}>
            {isBottomVisible ? localeMessages.hideButton : localeMessages.showButton}
        </span>;
        return (
            <div className="xl-react-widget-collapsible-bottom-split-pane">
                <SplitPane
                    {...this.props}
                    maxSize={minSizeBottom - minSizeTop}
                    minSize={minSizeBottom}
                    onChange={this.handlePaneHeightChange}
                    primary="second"
                    size={bottomPaneHeight}
                    split="horizontal">
                    {children[0]}
                    <div className={splitPaneClass}>
                        {children[1]}
                        {toggleButton}
                    </div>
                </SplitPane>
            </div>
        );
    }
}

==> xl-react-components-0.21.9.tgz: package/app/xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-bottom-split-pane/xl-react-widget-collapsible-bottom-split-pane-component.js <==
import PropTypes from 'prop-types';
import React, {Component} from 'react';
import SplitPane from 'react-split-pane';
import classnames from 'classnames';
import {localeMessages} from '../../../services/locale-service';

import './xl-react-widget-collapsible-bottom-split-pane.less';

export class XlReactWidgetCollapsibleBottomSplitPanel extends Component {
    static propTypes = {
        children: PropTypes.arrayOf(PropTypes.element.isRequired),
        defaultBottomPaneHeight: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        minSizeBottom: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        minSizeTop: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
    };

    state = {isBottomVisible: false};

    handleDisplayToggle = () => {
        if (this.state.isBottomVisible) {
            this.hideBottomPane();
        } else {
            this.showBottomPane();
        }
    };

    handlePaneHeightChange = (size) => {
        this.setState({isBottomVisible: size > this.props.minSizeBottom});
    };

    showBottomPane = () => {
        if (!this.state.isBottomVisible) {
            this.setState({
                bottomPaneHeight: this.props.defaultBottomPaneHeight,
                isBottomVisible: true
            });
        }
    };

    hideBottomPane = () => {
        if (this.state.isBottomVisible) {
            this.setState({
                bottomPaneHeight: this.props.minSizeBottom,
                isBottomVisible: false
            });
        }
    };

    render() {
        const {bottomPaneHeight, isBottomVisible} = this.state;
        const {minSizeTop, minSizeBottom, children} = this.props;
        const splitPaneClass = classnames({visible: isBottomVisible}, 'hideable-split-pane');
        const toggleClass = classnames('xl-icon', {
            'chevron-down-icon': isBottomVisible,
            'chevron-up-icon': !isBottomVisible
        });
        const toggleButton = <div className="toggle" onClick={this.handleDisplayToggle}>
            <i className={toggleClass}/>
            {isBottomVisible ? localeMessages.hideButton : localeMessages.showButton}
        </div>;
        return (
            <div className="xl-react-widget-collapsible-bottom-split-pane">
                <SplitPane
                    {...this.props}
                    maxSize={minSizeBottom - minSizeTop}
                    minSize={minSizeBottom}
                    onChange={this.handlePaneHeightChange}
                    primary="second"
                    resizerClassName="xl-icon options-icon"
                    size={bottomPaneHeight}
                    split="horizontal">
                    {children[0]}
                    <div className={splitPaneClass}>
                        {children[1]}
                        {toggleButton}
                    </div>
                </SplitPane>
            </div>
        );
    }
}
